/*******************************************************************************
* Title: IR_Sensors.h                                                                      
* Version: 1.0                                                                 
* Author: Jeff Nybo                                                            
* Date: April 23, 2014                                                                       
*                                                                              
* Description:                                                                 
* This file containts the functions that are used to calibrate and read the IR                                                                             
* sensors on the beer pong table. This allows us to detect when a cup has been                                                                             
* removed from or placed on a pod, and it allows us to detect when a ball has
* been dropped into either of the ballwashers.                                                                             
*******************************************************************************/

#ifndef IR_SENSORS_H
#define IR_SENSORS_H

/*************************************************
*                   Constants                    *
*************************************************/
//IR_TX1 controls the IR transmitters on all of the sensors for one end of the table
//IR_TX2 controls the IR transmitters on all of the sensors for the other end of the table
#define IR_TX1        _LATF1
#define IR_TX2        _LATF0

//Chip selects for each of the 74HC4051 8-channel multiplexers
#define IR_C1_EN      _LATD2
#define IR_C2_EN      _LATD3
#define IR_C3_EN      _LATD0
#define IR_C4_EN      _LATC13

//Pin selects for the (A = LSb <-> C = MSb)
#define IR_A_IN       _LATB13
#define IR_B_IN       _LATB14
#define IR_C_IN       _LATB15

//This adjusts the sensitivity of the IR sensors. Higher Value = Less Sensitive,
//Lower Value = More Sensitive (Value has to be between 0 and 1023 of course)
//BW_THRESHOLD is for the ball washers which we want to be a little more sensitive
#define IR_THRESHOLD        400
#define BW_THRESHOLD        150

//Determines the # of times each sensor will be read and averaged with.
//Do not go higher than 64. Explained in more detail in the 'C' file.
#define CAL_DIV       50

//The delay period in uS after each IR sensor ADC reading; If you are getting
//inconsistent values try increasing this. I can go as low as 13uS.
#define IR_DELAY      20

/*************************************************
*                   Macros                       *
*************************************************/

/*************************************************
*              Function Prototypes               *
*************************************************/
UINT32 Pack_Sensor_Data(void);

void Update_Sensors(void);
void Sensor_Calibration(void);
void Update_Ball_Washers(UINT16 *data);

#endif
